abeyance.n-u
abhorrence.n-u
abnormality.n-u
abstinence.n-u
absurdity.n-u
abundance.n-u
acceptability.n-u
acceptance.n-u
accessibility.n-u
accordance.n-u
accountability.n-u
accountancy.n-u
accuracy.n-u
acidity.n-u
acquaintance.n-u
activity.n-u
actuality.n-u
acuity.n-u
adaptability.n-u
adequacy.n-u
admissibility.n-u
admittance.n-u
adolescence.n-u
adversity.n-u
advisability.n-u
advocacy.n-u
affability.n-u
affinity.n-u
affluence.n-u
affordability.n-u
agility.n-u
alacrity.n-u
allegiance.n-u
alliance.n-u
ambiguity.n-u
ambivalence.n-u
amiability.n-u
amicability.n-u
amity.n-u
amorality.n-u
animosity.n-u
annoyance.n-u
anonymity.n-u
antecedence.n-u
antiquity.n-u
anxiety.n-u
applicability.n-u
aridity.n-u
aristocracy.n-u
arrogance.n-u
ascendancy.n-u
ascendency.n-u
asexuality.n-u
asperity.n-u
assistance.n-u
assonance.n-u
astringency.n-u
atonality.n-u
attendance.n-u
audacity.n-u
audibility.n-u
austerity.n-u
authenticity.n-u
authority.n-u
autocracy.n-u
availability.n-u
avoidance.n-u
balance.n-u
banality.n-u
bankruptcy.n-u
barbarity.n-u
beauty.n-u
belligerency.n-u
beneficence.n-u
benevolence.n-u
bestiality.n-u
biodiversity.n-u
bisexuality.n-u
booty.n-u
bounce.n-u
bounty.n-u
brevity.n-u
brilliance.n-u
brutality.n-u
buoyancy.n-u
bureaucracy.n-u
calmness.n-u
calm.n-u
capability.n-u
captivity.n-u
catholicity.n-u
causality.n-u
celebrity.n-u
celerity.n-u
celibacy.n-u
certainty.n-u
charity.n-u
chastity.n-u
circularity.n-u
civility.n-u
clairvoyance.n-u
clarity.n-u
clearance.n-u
clemency.n-u
coalescence.n-u
coexistence.n-u
cogency.n-u
cognizance.n-u
coherence.n-u
coincidence.n-u
comparability.n-u
compatibility.n-u
competence.n-u
complacence.n-u
complacency.n-u
complexity.n-u
compliance.n-u
complicity.n-u
comprehensibility.n-u
concavity.n-u
concordance.n-u
concurrence.n-u
condolence.n-u
conductivity.n-u
confidence.n-u
confidentiality.n-u
conformity.n-u
connectivity.n-u
connivance.n-u
consanguinity.n-u
consistency.n-u
consonance.n-u
constancy.n-u
constitutionality.n-u
contiguity.n-u
continence.n-u
contingency.n-u
continuity.n-u
convalescence.n-u
convenience.n-u
convergence.n-u
convertibility.n-u
convexity.n-u
conveyance.n-u
cordiality.n-u
corpulence.n-u
correspondence.n-u
countenance.n-u
counterintelligence.n-u
creativity.n-u
credence.n-u
credibility.n-u
credulity.n-u
crudity.n-u
cruelty.n-u
culpability.n-u
curiosity.n-u
currency.n-u
cybersecurity.n-u
dalliance.n-u
dance.n-u
debility.n-u
decadence.n-u
decency.n-u
deductibility.n-u
defence.n-u
deference.n-u
defiance.n-u
deficiency.n-u
deformity.n-u
delicacy.n-u
delinquency.n-u
deliverance.n-u
democracy.n-u
density.n-u
dependence.n-u
dependency.n-u
depravity.n-u
desirability.n-u
despondency.n-u
dexterity.n-u
difficulty.n-u
diffidence.n-u
dignity.n-u
diligence.n-u
diplomacy.n-u
directionality.n-u
disability.n-u
discontinuity.n-u
discrepancy.n-u
dishonesty.n-u
disloyalty.n-u
disobedience.n-u
dissidence.n-u
dissimilarity.n-u
dissonance.n-u
disturbance.n-u
disunity.n-u
divergence.n-u
diversity.n-u
divinity.n-u
docility.n-u
domesticity.n-u
dominance.n-u
duplicity.n-u
durability.n-u
duty.n-u
ebullience.n-u
eccentricity.n-u
effervescence.n-u
efficacy.n-u
efficiency.n-u
efflorescence.n-u
elasticity.n-u
electricity.n-u
elegance.n-u
eligibility.n-u
eloquence.n-u
emergency.n-u
eminence.n-u
endurance.n-u
enmity.n-u
enormity.n-u
entirety.n-u
entrance.n-u
equality.n-u
equanimity.n-u
equity.n-u
equivalence.n-u
essence.n-u
eternity.n-u
ethnicity.n-u
evanescence.n-u
excellence.n-u
excitability.n-u
exclusivity.n-u
existence.n-u
expectancy.n-u
expediency.n-u
experience.n-u
extravagance.n-u
exuberance.n-u
facility.n-u
fallibility.n-u
falsity.n-u
familiarity.n-u
fancy.n-u
fealty.n-u
feasibility.n-u
fecundity.n-u
felicity.n-u
femininity.n-u
ferocity.n-u
fertility.n-u
festivity.n-u
fidelity.n-u
finality.n-u
finance.n-u
flaccidity.n-u
flamboyance.n-u
flatulence.n-u
flexibility.n-u
flippancy.n-u
fluency.n-u
fluidity.n-u
fluorescence.n-u
forbearance.n-u
formality.n-u
fragility.n-u
fragrance.n-u
frailty.n-u
fraternity.n-u
frequency.n-u
frigidity.n-u
frivolity.n-u
frugality.n-u
functionality.n-u
furtherance.n-u
futility.n-u
gaiety.n-u
generality.n-u
generosity.n-u
geniality.n-u
gentility.n-u
governance.n-u
grandiloquence.n-u
gravity.n-u
guidance.n-u
gullibility.n-u
heredity.n-u
hesitancy.n-u
heterosexuality.n-u
hilarity.n-u
homogeneity.n-u
homosexuality.n-u
honesty.n-u
hospitality.n-u
hostility.n-u
humanity.n-u
humidity.n-u
humility.n-u
idempotence.n-u
identity.n-u
idiocy.n-u
ignorance.n-u
illegality.n-u
illegibility.n-u
illegitimacy.n-u
illiteracy.n-u
imbalance.n-u
imbecility.n-u
immanence.n-u
immaturity.n-u
immediacy.n-u
immensity.n-u
imminence.n-u
immobility.n-u
immodesty.n-u
immorality.n-u
immortality.n-u
immunity.n-u
impartiality.n-u
impassivity.n-u
impatience.n-u
impermanence.n-u
impertinence.n-u
impiety.n-u
implausibility.n-u
importance.n-u
impossibility.n-u
impotence.n-u
impracticability.n-u
impregnability.n-u
improbability.n-u
impropriety.n-u
imprudence.n-u
impudence.n-u
impunity.n-u
impurity.n-u
inability.n-u
inaccessibility.n-u
inaccuracy.n-u
inactivity.n-u
inadequacy.n-u
inadvisability.n-u
inanity.n-u
inaudibility.n-u
incandescence.n-u
incapability.n-u
incapacity.n-u
incivility.n-u
incoherence.n-u
incompatibility.n-u
incompetence.n-u
incomprehensibility.n-u
incongruity.n-u
inconsistency.n-u
incontinence.n-u
inconvenience.n-u
incorruptibility.n-u
incredulity.n-u
indecency.n-u
indemnity.n-u
independence.n-u
indestructibility.n-u
indeterminacy.n-u
indifference.n-u
indispensability.n-u
individuality.n-u
indolence.n-u
indulgence.n-u
ineffectuality.n-u
inefficiency.n-u
inelegance.n-u
ineligibility.n-u
inequality.n-u
inequity.n-u
inevitability.n-u
inexperience.n-u
infallibility.n-u
infancy.n-u
inference.n-u
inferiority.n-u
infertility.n-u
infidelity.n-u
infinity.n-u
infirmity.n-u
inflexibility.n-u
influence.n-u
informality.n-u
ingenuity.n-u
inheritance.n-u
inhumanity.n-u
iniquity.n-u
innocence.n-u
insanity.n-u
insecurity.n-u
insensitivity.n-u
insignificance.n-u
insincerity.n-u
insolence.n-u
insolvency.n-u
instability.n-u
insufficiency.n-u
insularity.n-u
insurance.n-u
intangibility.n-u
integrity.n-u
intelligence.n-u
intelligibility.n-u
intemperance.n-u
interference.n-u
interoperability.n-u
intimacy.n-u
intolerance.n-u
intractability.n-u
intransigence.n-u
intricacy.n-u
invalidity.n-u
invincibility.n-u
invisibility.n-u
irascibility.n-u
irregularity.n-u
irrelevance.n-u
irrelevancy.n-u
irresponsibility.n-u
irreverence.n-u
irreversibility.n-u
irritability.n-u
issuance.n-u
jocularity.n-u
jollity.n-u
joviality.n-u
jurisprudence.n-u
latency.n-u
laxity.n-u
legality.n-u
legibility.n-u
legitimacy.n-u
lenience.n-u
leniency.n-u
levity.n-u
liability.n-u
liberality.n-u
liberty.n-u
licence.n-u
liquidity.n-u
literacy.n-u
locality.n-u
longevity.n-u
loyalty.n-u
lucidity.n-u
luminosity.n-u
lunacy.n-u
luxuriance.n-u
magnanimity.n-u
magnificence.n-u
maintenance.n-u
majesty.n-u
malevolence.n-u
malfeasance.n-u
malignancy.n-u
malleability.n-u
manageability.n-u
manoeuvrability.n-u
marriageability.n-u
masculinity.n-u
maternity.n-u
maturity.n-u
mediocrity.n-u
mentality.n-u
mercy.n-u
militancy.n-u
mince.n-u
mobility.n-u
modernity.n-u
modesty.n-u
monstrosity.n-u
morality.n-u
morbidity.n-u
mortality.n-u
motility.n-u
multiplicity.n-u
munificence.n-u
mutability.n-u
naivety.n-u
nationality.n-u
navigability.n-u
necessity.n-u
negligence.n-u
neutrality.n-u
nobility.n-u
nonchalance.n-u
nonconformity.n-u
nonviolence.n-u
normalcy.n-u
normality.n-u
notoriety.n-u
novelty.n-u
nuance.n-u
nudity.n-u
numeracy.n-u
obduracy.n-u
obedience.n-u
obeisance.n-u
obesity.n-u
objectivity.n-u
obscenity.n-u
obscurity.n-u
observance.n-u
obsolescence.n-u
obstinacy.n-u
occurrence.n-u
offence.n-u
omnipotence.n-u
omniscience.n-u
opacity.n-u
opulence.n-u
originality.n-u
overconfidence.n-u
paederasty.n-u
parity.n-u
passivity.n-u
paternity.n-u
patience.n-u
patternicity.n-u
paucity.n-u
peculiarity.n-u
pederasty.n-u
penalty.n-u
penance.n-u
penitence.n-u
perceptibility.n-u
perfectibility.n-u
performance.n-u
permanence.n-u
permeability.n-u
perpetuity.n-u
perplexity.n-u
perseverance.n-u
persistence.n-u
personality.n-u
perspicacity.n-u
perspicuity.n-u
pertinence.n-u
perversity.n-u
pestilence.n-u
petulance.n-u
phosphorescence.n-u
piety.n-u
piquancy.n-u
piracy.n-u
pity.n-u
placidity.n-u
planarity.n-u
plasticity.n-u
plausibility.n-u
pliancy.n-u
plurality.n-u
plutocracy.n-u
poignancy.n-u
polarity.n-u
policy.n-u
pomposity.n-u
popularity.n-u
porosity.n-u
portability.n-u
posterity.n-u
potency.n-u
potentiality.n-u
poverty.n-u
practicability.n-u
practicality.n-u
precedence.n-u
precocity.n-u
predictability.n-u
predominance.n-u
preference.n-u
pregnancy.n-u
prescience.n-u
presence.n-u
pretence.n-u
prevalence.n-u
primacy.n-u
priority.n-u
privacy.n-u
probity.n-u
productivity.n-u
profanity.n-u
proficiency.n-u
profitability.n-u
profligacy.n-u
profundity.n-u
prolixity.n-u
prominence.n-u
promiscuity.n-u
property.n-u
prophecy.n-u
propriety.n-u
prosperity.n-u
provenance.n-u
providence.n-u
proximity.n-u
prudence.n-u
prurience.n-u
puberty.n-u
publicity.n-u
pugnacity.n-u
punctuality.n-u
pungency.n-u
purity.n-u
pusillanimity.n-u
putty.n-u
quality.n-u
quiet.n-u
quince.n-u
radiance.n-u
radioactivity.n-u
rapacity.n-u
rapidity.n-u
rarity.n-u
rationality.n-u
readability.n-u
reactivity.n-u
reality.n-u
recalcitrance.n-u
receptivity.n-u
reciprocity.n-u
reconnaissance.n-u
recurrence.n-u
redundancy.n-u
reference.n-u
regularity.n-u
relativity.n-u
relevancy.n-u
reliability.n-u
reliance.n-u
remembrance.n-u
reminiscence.n-u
remittance.n-u
remonstrance.n-u
repeatability.n-u
repentance.n-u
reproducibility.n-u
repugnance.n-u
resemblance.n-u
residence.n-u
resilience.n-u
resiliency.n-u
resistance.n-u
resolvability.n-u
resonance.n-u
respectability.n-u
resplendence.n-u
reticence.n-u
reverence.n-u
reversibility.n-u
riddance.n-u
rigidity.n-u
romance.n-u
royalty.n-u
safety.n-u
sagacity.n-u
salience.n-u
salinity.n-u
sanctity.n-u
sanity.n-u
satiety.n-u
satisfiability.n-u
scalability.n-u
scarcity.n-u
science.n-u
secrecy.n-u
security.n-u
selectivity.n-u
self-confidence.n-u
self-indulgence.n-u
self-pity.n-u
self-sufficiency.n-u
semblance.n-u
senility.n-u
seniority.n-u
sensibility.n-u
sensitivity.n-u
sensuality.n-u
sentimentality.n-u
sequence.n-u
serendipity.n-u
serenity.n-u
severance.n-u
severity.n-u
sexuality.n-u
significance.n-u
silence.n-u
similarity.n-u
simplicity.n-u
simultaneity.n-u
sincerity.n-u
sobriety.n-u
sociability.n-u
society.n-u
solemnity.n-u
solidarity.n-u
solidity.n-u
solubility.n-u
solvency.n-u
somnolence.n-u
sonority.n-u
sovereignty.n-u
specificity.n-u
spirituality.n-u
spontaneity.n-u
stability.n-u
sterility.n-u
stringency.n-u
stupidity.n-u
suavity.n-u
subjectivity.n-u
submergence.n-u
subservience.n-u
subsistence.n-u
substance.n-u
subtlety.n-u
sufficiency.n-u
suitability.n-u
superconductivity.n-u
superficiality.n-u
superfluity.n-u
superiority.n-u
supremacy.n-u
surveillance.n-u
susceptibility.n-u
sustainability.n-u
sustenance.n-u
technocracy.n-u
temerity.n-u
temperance.n-u
temporality.n-u
tenacity.n-u
tenancy.n-u
theocracy.n-u
timidity.n-u
tolerance.n-u
tonality.n-u
totality.n-u
toxicity.n-u
traceability.n-u
tranquility.n-u
tranquillity.n-u
transcendence.n-u
transference.n-u
transience.n-u
translucence.n-u
transparency.n-u
treaty.n-u
triviality.n-u
truancy.n-u
truculence.n-u
turbulence.n-u
ubiquity.n-u
unanimity.n-u
uncertainty.n-u
unfamiliarity.n-u
uniformity.n-u
unity.n-u
universality.n-u
unpopularity.n-u
unpredictability.n-u
unreality.n-u
unsuitability.n-u
urbanity.n-u
urgency.n-u
usability.n-u
utility.n-u
utterance.n-u
vacancy.n-u
vacuity.n-u
vagrancy.n-u
validity.n-u
vanity.n-u
variability.n-u
variance.n-u
variety.n-u
varsity.n-u
vehemence.n-u
velocity.n-u
vengeance.n-u
veracity.n-u
verbosity.n-u
versatility.n-u
viability.n-u
vicinity.n-u
vigilance.n-u
violence.n-u
virginity.n-u
virility.n-u
virtuosity.n-u
virulence.n-u
viscosity.n-u
visibility.n-u
vitality.n-u
vivacity.n-u
volatility.n-u
vulgarity.n-u
vulnerability.n-u
